<?php
/**
 * @package     CSVI
 * @subpackage  Templates
 *
 * @author      RolandD Cyber Produksi <contact@rolandd.com>
 * @copyright   Copyright (C) 2006 - [year] RolandD Cyber Produksi. All rights reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 * @link        https://rolandd.com
 */

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Layout\LayoutHelper;
use Joomla\CMS\Router\Route;
use Joomla\CMS\Session\Session;
use Joomla\CMS\Version;

defined('_JEXEC') or die;

if (Version::MAJOR_VERSION === 3)
{
	HTMLHelper::_('bootstrap.tooltip');
	HTMLHelper::_('behavior.multiselect');
	HTMLHelper::_('formbehavior.chosen');
}
else {
	/** @var \Joomla\CMS\WebAsset\WebAssetManager $wa */
	$wa = $this->document->getWebAssetManager();
	$wa->useScript('table.columns');
}

$listOrder  = $this->escape($this->state->get('list.ordering'));
$listDirn   = $this->escape($this->state->get('list.direction'));

$loggeduser = Factory::getUser();
$saveOrder = $listOrder === 'templates.ordering';
$saveOrderingUrl = '';

if ($saveOrder)
{
	$saveOrderingUrl = 'index.php?option=com_csvi&task=templates.saveOrderAjax&tmpl=component&' . Session::getFormToken() . '=1';

	if (Version::MAJOR_VERSION === 3)
	{
		HTMLHelper::_('sortablelist.sortable', 'templatesList', 'adminForm', strtolower($listDirn), $saveOrderingUrl);
	}
	else if (in_array(Version::MAJOR_VERSION, [4,5], true))
	{
		HTMLHelper::_('draggablelist.draggable', 'templatesList', 'adminForm', strtolower($listDirn), $saveOrderingUrl);
	}
}
?>
<form action="<?php echo Route::_('index.php?option=com_csvi&view=templates'); ?>" method="post" name="adminForm" id="adminForm" class="form-horizontal">
	<?php if (Version::MAJOR_VERSION === 3) : ?>
		<div id="j-sidebar-container" class="span2">
			<?php echo $this->sidebar; ?>
		</div>
	<?php endif; ?>
	<div id="j-main-container" class="span10">
		<?php echo LayoutHelper::render('joomla.searchtools.default', ['view' => $this]); ?>
		<?php if (empty($this->items)) : ?>
			<div class="alert alert-info">
				<span class="icon-info-circle" aria-hidden="true"></span><span class="visually-hidden"><?php echo Text::_('INFO'); ?></span>
				<?php echo Text::_('JGLOBAL_NO_MATCHING_RESULTS'); ?>
			</div>
		<?php else : ?>
			<table class="table table-striped" id="templatesList">
				<thead>
				<tr>
					<th width="1%" class="nowrap center hidden-phone">
						<?php echo HTMLHelper::_('searchtools.sort', '', 'templates.ordering', $listDirn, $listOrder, null, 'asc', 'JGRID_HEADING_ORDERING', 'icon-menu-2'); ?>
					</th>
					<th width="1%" class="nowrap center">
						<?php echo HTMLHelper::_('grid.checkall'); ?>
					</th>
					<th class="left">
						<?php echo HTMLHelper::_('searchtools.sort', 'COM_CSVI_TEMPLATES_FEATURED', 'templates.featured', $listDirn, $listOrder); ?>
					</th>
					<th class="left">
						<?php echo HTMLHelper::_('searchtools.sort', 'COM_CSVI_TEMPLATES_FIELD_NAME', 'templates.template_name', $listDirn, $listOrder); ?>
					</th>
					<th class="nowrap">
						<?php echo HTMLHelper::_('searchtools.sort', 'COM_CSVI_TEMPLATES_FIELD_ACTION', 'templates.action', $listDirn, $listOrder); ?>
					</th>
					<th class="nowrap">
						<?php echo HTMLHelper::_('searchtools.sort', 'COM_CSVI_TEMPLATES_FIELD_ENABLED', 'templates.enabled', $listDirn, $listOrder); ?>
					</th>
					<th class="nowrap">
						<?php echo HTMLHelper::_('searchtools.sort', 'COM_CSVI_TEMPLATES_FIELD_FRONTEND', 'templates.frontend', $listDirn, $listOrder); ?>
					</th>
					<th class="nowrap">
						<?php echo HTMLHelper::_('searchtools.sort', 'COM_CSVI_TEMPLATES_FIELD_LASTRUN', 'templates.lastrun', $listDirn, $listOrder); ?>
					</th>
					<th>
						<?php echo Text::_('COM_CSVI_RUN'); ?>
					</th>
				</tr>
				</thead>
				<?php if (Version::MAJOR_VERSION === 3) : ?>
					<tfoot>
					<tr>
						<td colspan="15">
							<div class="pull-left">
								<?php
								if ($this->pagination->total > 0)
								{
									echo $this->pagination->getListFooter();
								}
								?>
							</div>
							<div class="pull-right"><?php echo $this->pagination->getResultsCounter(); ?></div>
						</td>
					</tr>
					</tfoot>
				<?php endif; ?>
				<tbody class="js-draggable" data-url="<?php echo $saveOrderingUrl; ?>" data-direction="<?php echo strtolower($listDirn); ?>">
				<?php
				$canEdit   = $this->canDo->get('core.edit');
				$canChange = $loggeduser->authorise('core.edit.state', 'com_csvi');

				foreach ($this->items as $i => $item) :

					$primary = false;

					if ($i === 0)
					{
						$primary = true;
					}
					?>
					<tr>
						<td class="order nowrap center hidden-phone">
							<?php
							$iconClass = '';

							if (!$canChange)
							{
								$iconClass = ' inactive';
							}
							elseif (!$saveOrder)
							{
								$iconClass = ' inactive tip-top hasTooltip" title="' . HTMLHelper::tooltipText('JORDERINGDISABLED');
							}
							?>
							<span class="sortable-handler <?php echo $iconClass ?>">
                                <span class="<?php echo (Version::MAJOR_VERSION === 3) ? 'icon-menu' : 'icon-ellipsis-v'; ?>" aria-hidden="true"></span>
                            </span>
							<?php if ($canChange && $saveOrder) : ?>
								<input type="text" style="display:none" name="order[]" size="5"
								       value="<?php echo $item->ordering; ?>" class="width-20 text-area-order hidden" />
							<?php endif; ?>
						</td>
						<td class="center">
							<?php if ($canEdit || $canChange) : ?>
								<?php echo HTMLHelper::_('grid.id', $i, $item->csvi_template_id); ?>
							<?php endif; ?>
						</td>
						<td>
							<a href="#"
							   class='btn btn-micro active hasTooltip tbody-icon'
							   onclick="Joomla.listItemTask('cb<?php echo $i; ?>', '<?php echo ($item->featured) ? 'templates.unfeatured' : 'templates.featured'; ?>')">
								<i class="<?php echo ($item->featured) ? 'icon-star icon-featured icon-color-featured' : 'icon-star-empty'; ?>"></i>
							</a>
						</td>
						<td>
							<div class="name break-word">
								<?php if ($canEdit)
								{
									echo HTMLHelper::_(
										'link',
										Route::_('index.php?option=com_csvi&task=template.edit&csvi_template_id=' . (int) $item->csvi_template_id),
										$this->escape($item->template_name),
										'title="' . Text::sprintf('COM_CSVI_EDIT_TEMPLATE', $this->escape($item->template_name)) . '"'
									);
								}
								else
								{
									echo $this->escape($item->template_name);
								}
								?>
								<span class="small"><?php echo Text::sprintf('COM_CSV_TEMPLATE_LIST_ALIAS', $item->template_alias); ?></span>
							</div>
						</td>
						<td class="break-word">
							<?php echo $this->escape($item->action); ?>
						</td>
						<td class="small">
							<?php echo HTMLHelper::_('jgrid.published', $item->enabled, $i, 'templates.', $canChange); ?>
						</td>
						<td class="small">
							<?php echo HTMLHelper::_('jgrid.published', $item->frontend, $i, 'templates.', false); ?>
						</td>
						<td class="break-word">
							<?php
								$displayDate = Text::_('COM_CSVI_TEMPLATE_NEVER_RUN');

								if ($item->lastrun !== $this->db->getNullDate())
								{
									$displayDate = HTMLHelper::_('date', $item->lastrun, 'd-m-Y H:i:s');
								}

								echo $displayDate;
							?>
						</td>
						<td>
							<?php
								$task = $item->action === 'import' ? 'imports.selectsource' : 'export.start';
								echo HTMLHelper::_(
									'link',
									Route::_('index.php?option=com_csvi&task=' . $task . '&csvi_template_id=' . (int) $item->csvi_template_id),
									Text::_('COM_CSVI_RUN'),
									'class="btn btn-primary btn-small"'
								);
							?>
						</td>
					</tr>
				<?php endforeach; ?>
				</tbody>
			</table>

			<?php if (in_array(Version::MAJOR_VERSION, [4,5], true)) : ?>
				<?php echo $this->pagination->getListFooter(); ?>
			<?php endif; ?>
		<?php endif; ?>
	</div>
	<input type="hidden" name="task" value="" />
	<input type="hidden" name="boxchecked" value="0" />
	<?php echo HTMLHelper::_('form.token'); ?>
</form>
<script>
	Joomla.submitbutton = function (task) {

		Joomla.submitform(task, document.getElementById('adminForm'));

		if (task === 'templates.backupTemplates') {
			document.adminForm.task.value = '';
		}
	}
</script>
